OC.L10N.register(
    "spreed",
    {
    "a conversation" : "percakapan",
    "(Duration %s)" : "(Durasi %s)",
    "You attended a call with {user1}" : "Anda menghadiri panggilan dengan {user1}",
    "_%n guest_::_%n guests_" : ["%n tamu"],
    "You attended a call with {user1} and {user2}" : "Anda menghadiri panggilan dengan {user1} dan {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Anda menghadiri panggilan dengan {user1}, {user2} dan {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Anda menghadiri panggilan dengan {user1}, {user2}, {user3} dan {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Anda menghadiri panggilan dengan {user1}, {user2}, {user3}, {user4} dan {user5}",
    "{actor} invited you to {call}" : "{actor} mengundang Anda untuk {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Anda diundang dalam <strong>percakapan</strong> atau mendapat <strong>panggilan</strong>",
    "Other activities" : "Aktivitas lain",
    "Talk" : "Talk",
    "Guest" : "Tamu",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge dan Safari sekarang dapat digunakan untuk berpartisipasi dalam panggilan audio dan video",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Sekarang Anda dapat memberi tahu semua peserta dengan memposting \"@all\" ke dalam obrolan",
    "- With the \"arrow-up\" key you can repost your last message" : "- Dengan tombol \"panah-atas\" Anda dapat memposting ulang pesan terakhir Anda",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk sekarang dapat memiliki perintah, kirim \"/help\" sebagai pesan obrolan untuk melihat apakah administrator Anda mengonfigurasi beberapa",
    "- You can now mention guests in the chat" : "- Anda sekarang dapat menyebut tamu di obrolan",
    "{actor} created the conversation" : "{actor} membuat sebuah percakapan",
    "You created the conversation" : "Anda membuat sebuah percakapan",
    "Message deleted by author" : "Pesan dihapus oleh penyusun",
    "Administration" : "Administrasi",
    "System" : "Sistem",
    "File is too big" : "Berkas terlalu besar",
    "Invalid file provided" : "Berkas tidak valid",
    "Invalid image" : "Gambar tidak valid",
    "Unknown filetype" : "Tipe berkas tak dikenal",
    "Say hi to your friends and colleagues!" : "Katakan halo kepada teman dan kolega Anda!",
    "You were mentioned" : "Anda disebutkan",
    "Dismiss notification" : "Abaikan notifikasi",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "error" : "galat",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Uni Emirat Arab",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua dan Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antartika",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Amerika",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Pulau Åland",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia dan Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgium",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthelemy",
    "Bermuda" : "Bermuda",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius dan Saba",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Pulau Cocos (Keeling)",
    "Central African Republic" : "Republik Afrika Tengah",
    "Congo" : "Congo",
    "Switzerland" : "Swiss",
    "Cook Islands" : "Pulau Cook",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "Cina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Pulau Natal",
    "Cyprus" : "Cyprus",
    "Germany" : "Jerman",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominican Republic" : "Republik Dominika",
    "Algeria" : "Algeria",
    "Ecuador" : "Ekuador",
    "Estonia" : "Estonia",
    "Egypt" : "Mesir",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanyol",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fiji",
    "Faroe Islands" : "Pulau Faroe",
    "France" : "Prancis",
    "Gabon" : "Gabon",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guyana Prancis",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Guinea Khatulistiwa",
    "Greece" : "Yunani",
    "South Georgia and the South Sandwich Islands" : "Georgia Selatan dan Kepulauan Sandwich Selatan",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Pulau Heard dan Kepulauan McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungaria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlandia",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Wilayah Samudra Hindia Inggris",
    "Iraq" : "Irak",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordan",
    "Japan" : "Jepang",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgizstan",
    "Cambodia" : "Kambodia",
    "Kiribati" : "Kiribati",
    "Saint Kitts and Nevis" : "Saint Kitts dan Nevis",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Kepulauan Cayman",
    "Kazakhstan" : "Kazakhstan",
    "Lebanon" : "Lebanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Kepulauan Marshall",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Kepulauan Mariana Utara",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Kaledonia Baru",
    "Niger" : "Niger",
    "Norfolk Island" : "Kepulauan Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Belanda",
    "Norway" : "Norwegia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Selandia Baru",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Polinesia Prancis",
    "Papua New Guinea" : "Papua Nugini",
    "Philippines" : "Filipina",
    "Pakistan" : "Pakistan",
    "Poland" : "Polandia",
    "Saint Pierre and Miquelon" : "Saint Pierre dan Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugis",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arab Saudi",
    "Solomon Islands" : "Kepulauan Solomon",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Swedia",
    "Singapore" : "Singapora",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension dan Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard dan Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudan Selatan",
    "Sao Tome and Principe" : "Sao Tome dan Principe",
    "El Salvador" : "El Salvador",
    "Turks and Caicos Islands" : "Kepulauan Turks dan Caicos",
    "Chad" : "Chad",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turki",
    "Trinidad and Tobago" : "Trinidad dan Tobago",
    "Tuvalu" : "Tuvalu",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Pulau Kecil Terluar Amerika Serikat",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent dan Grenadine",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis dan Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Afrika Selatan",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Federation" : "Federasi",
    "Invalid date, date format must be YYYY-MM-DD" : "Tanggal salah, format tanggal harus TTTT-BB-HH",
    "Request password" : "Minta kata sandi",
    "Everyone" : "Semua orang",
    "Save changes" : "Simpan perubahan",
    "Saving …" : "Menyimpan ...",
    "Limit to groups" : "Batasi ke grup",
    "Enabled" : "Diaktifkan",
    "Disabled" : "Dinonaktifkan",
    "State" : "Kondisi",
    "Name" : "Nama",
    "Description" : "Deskrisi",
    "Off" : "Nonaktif",
    "Enable encryption" : "Aktifkan enkripsi",
    "Pending" : "Tunggu",
    "Error" : "Kesalahan",
    "Language" : "Bahasa",
    "Country" : "Negara",
    "Status" : "Status",
    "Created at" : "Dibuat saat",
    "Failed" : "Gagal",
    "OK" : "OK",
    "Confirm" : "Konfirmasi",
    "Reset" : "Setel ulang",
    "Back" : "Kembali",
    "Cancel" : "Membatalkan",
    "Loading …" : "Memuat …",
    "No upcoming events" : "Tdak ada acara mendatang",
    "Calendar" : "Kalender",
    "Attendees" : "Peserta",
    "Save" : "Simpan",
    "No results" : "Tidak ada hasil",
    "Done" : "Selesai",
    "Copy link" : "Salin tautan",
    "Collapse" : "Tutup",
    "Expand" : "Perluas",
    "Drop your files to upload" : "Lepas berkas Anda untuk mengunggah",
    "Favorite" : "Favorit",
    "Date:" : "Tanggal:",
    "Hide details" : "Sembunyikan detail",
    "Show details" : "Tampilkan detail",
    "Disable" : "Nonaktifkan",
    "Enable" : "Aktifkan",
    "Choose" : "Pilih",
    "Restricted" : "Terbatas",
    "Personal" : "Pribadi",
    "Meeting" : "Rapat",
    "Password protection" : "Password protection",
    "Edit" : "Sunting",
    "Delete" : "Hapus",
    "Notifications" : "Pemberitahuan",
    "Create conversation" : "Buat percakapan",
    "Log in" : "Masuk",
    "Mark as read" : "tandai sudah dibaca",
    "Mark as unread" : "Tandai belum dibaca",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Tambah ke favorit",
    "Clear filter" : "Bersihkan filter",
    "Users" : "Pengguna",
    "Groups" : "Grup",
    "No search results" : "Tidak ada hasil pencarian",
    "None" : "Tidak ada",
    "Invalid path selected" : "Jalur terpilih invalid",
    "Blur" : "Kabur",
    "Upload" : "Unggah",
    "Files" : "Berkas",
    "Unread messages" : "Pesan belum dibaca",
    "Reply" : "Balas",
    "Translate" : "Terjemahkan",
    "Dismiss" : "Batal",
    "Contact" : "Kontak",
    "Today" : "Hari ini",
    "Yesterday" : "Kemarin",
    "_%n day ago_::_%n days ago_" : ["%n hari yang lalu"],
    "Add participants" : "Tambahkan peserta",
    "Allow guests to join via link" : "Izinkan tamu untuk bergabung melalui tautan",
    "New file" : "File baru",
    "Blank" : "Kosong",
    "Send" : "Kirim",
    "Settings" : "Setelan",
    "Join" : "Gabung",
    "guest" : "pengunjung",
    "Remove" : "Hapus",
    "Add users or groups" : "Add users or groups",
    "Integrations" : "Integrasi",
    "Search or add participants" : "Cari atau tambah peserta",
    "An error occurred while adding the participants" : "Terjadi kesalahan saat menambahkan peserta",
    "You have new unread messages in the chat." : "Anda memiliki pesan baru yang belum dibaca dalam obrolan.",
    "Details" : "Detail",
    "Load more results" : "Muat lebih banyak hasil",
    "Projects" : "Proyek",
    "Search conversations or users" : "Cari percakapan atau pengguna",
    "Choose devices" : "Pilih perangkat",
    "Attachments folder" : "Folder lampiran",
    "Appearance" : "Tampilan",
    "Privacy" : "Privasi",
    "Performance" : "Performa",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Search" : "Cari",
    "Grid view" : "Tampilan kotak",
    "Join a conversation or start a new one!" : "Gabung dengan percakapan atau mulai yang baru!",
    "Join a conversation or start a new one" : "Gabung dengan percakapan atau mulai yang baru",
    "User" : "Pengguna",
    "Password" : "Kata kunci",
    "API token" : "Token API",
    "Login" : "Log masuk",
    "Nickname" : "Nama panggilan",
    "Client ID" : "ID Klien",
    "Media" : "Media",
    "Locations" : "Lokasi",
    "Audio" : "Audio",
    "Other" : "Lainnya",
    "Show all files" : "Tampilkan semua berkas",
    "Group" : "Grup",
    "Please reload the page." : "Silakan muat ulang halaman.",
    "Do not disturb" : "Jangan diganggu",
    "Away" : "Jauh",
    "Default" : "Bawaan",
    "The password is wrong. Try again." : "Kata sandi salah. Coba lagi",
    "Android app" : "Aplikasi Android",
    "iOS app" : "Aplikasi iOS",
    "__language_name__" : "Bahasa Indonesia",
    "Call summary (%s)" : "Ringkasan panggilan ( %s )",
    "Tasks" : "Tugas",
    "Notes" : "Catatan",
    "Reports" : "Laporan",
    "Call summary - {title}" : "Ringkasan panggilan - {judul}",
    "Loading" : "Memuat",
    "Close" : "Tutup",
    "Password protect" : "Lindungi dengan kata sandi"
},
"nplurals=1; plural=0;");
